summaryrefslogtreecommitdiff
path: root/indra/newview/llurldispatcher.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llurldispatcher.h')
-rw-r--r--indra/newview/llurldispatcher.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/indra/newview/llurldispatcher.h b/indra/newview/llurldispatcher.h
index 15e3ec73d8..ff8a351253 100644
--- a/indra/newview/llurldispatcher.h
+++ b/indra/newview/llurldispatcher.h
@@ -32,14 +32,14 @@
#ifndef LLURLDISPATCHER_H
#define LLURLDISPATCHER_H
-class LLWebBrowserCtrl;
+class LLMediaCtrl;
class LLURLDispatcher
{
public:
static bool dispatch(const std::string& url,
- LLWebBrowserCtrl* web,
+ LLMediaCtrl* web,
bool trusted_browser);
// At startup time and on clicks in internal web browsers,
// teleport, open map, or run requested command.
@@ -48,7 +48,7 @@ public:
// secondlife:///app/agent/3d6181b0-6a4b-97ef-18d8-722652995cf1/show
// sl://app/foo/bar
// @param web
// Pointer to LLWebBrowserCtrl sending URL, can be NULL
// @param trusted_browser
// True if coming inside the app AND from a brower instance
// that navigates to trusted (Linden Lab) pages.
@@ -48,7 +48,7 @@ public:
// sl://app/foo/bar
// @param web
- // Pointer to LLWebBrowserCtrl sending URL, can be NULL
+ // Pointer to LLMediaCtrl sending URL, can be NULL
// @param trusted_browser
// True if coming inside the app AND from a brower instance